@@ -4,8 +4,13 @@
 package config
 
 import (
+	"cmp"
+	"errors"
 	"fmt"
+	"io/fs"
 	"os"
+	"slices"
+	"strings"
 
 	"github.com/derailed/k9s/internal/config/data"
 	"github.com/derailed/k9s/internal/config/json"
@@ -25,6 +30,36 @@ type ViewSetting struct {
 	SortColumn string   `yaml:"sortColumn"`
 }
 
+func (v *ViewSetting) HasCols() bool {
+	return len(v.Columns) > 0
+}
+
+func (v *ViewSetting) IsBlank() bool {
+	return v == nil || len(v.Columns) == 0
+}
+
+func (v *ViewSetting) SortCol() (string, bool, error) {
+	if v == nil || v.SortColumn == "" {
+		return "", false, fmt.Errorf("no sort column specified")
+	}
+	tt := strings.Split(v.SortColumn, ":")
+	if len(tt) < 2 {
+		return "", false, fmt.Errorf("invalid sort column spec: %q. must be col-name:asc|desc", v.SortColumn)
+	}
+
+	return tt[0], tt[1] == "desc", nil
+}
+
+func (v *ViewSetting) Equals(vs *ViewSetting) bool {
+	if v == nil || vs == nil {
+		return v == nil && vs == nil
+	}
+	if c := slices.Compare(v.Columns, vs.Columns); c != 0 {
+		return false
+	}
+	return cmp.Compare(v.SortColumn, vs.SortColumn) == 0
+}
+
 // CustomView represents a collection of view customization.
 type CustomView struct {
 	Views     map[string]ViewSetting `yaml:"views"`
@@ -48,7 +83,7 @@ func (v *CustomView) Reset() {
 
 // Load loads view configurations.
 func (v *CustomView) Load(path string) error {
-	if _, err := os.Stat(path); os.IsNotExist(err) {
+	if _, err := os.Stat(path); errors.Is(err, fs.ErrNotExist) {
 		return nil
 	}
 	bb, err := os.ReadFile(path)
