@@ -10,6 +10,7 @@ import (
 	"strings"
 
 	"github.com/derailed/k9s/internal/client"
+	"github.com/derailed/k9s/internal/model1"
 	v1 "k8s.io/api/core/v1"
 	"k8s.io/apimachinery/pkg/apis/meta/v1/unstructured"
 	"k8s.io/apimachinery/pkg/runtime"
@@ -21,23 +22,23 @@ type Service struct {
 }
 
 // Header returns a header row.
-func (Service) Header(ns string) Header {
-	return Header{
-		HeaderColumn{Name: "NAMESPACE"},
-		HeaderColumn{Name: "NAME"},
-		HeaderColumn{Name: "TYPE"},
-		HeaderColumn{Name: "CLUSTER-IP"},
-		HeaderColumn{Name: "EXTERNAL-IP"},
-		HeaderColumn{Name: "SELECTOR", Wide: true},
-		HeaderColumn{Name: "PORTS", Wide: false},
-		HeaderColumn{Name: "LABELS", Wide: true},
-		HeaderColumn{Name: "VALID", Wide: true},
-		HeaderColumn{Name: "AGE", Time: true},
+func (Service) Header(ns string) model1.Header {
+	return model1.Header{
+		model1.HeaderColumn{Name: "NAMESPACE"},
+		model1.HeaderColumn{Name: "NAME"},
+		model1.HeaderColumn{Name: "TYPE"},
+		model1.HeaderColumn{Name: "CLUSTER-IP"},
+		model1.HeaderColumn{Name: "EXTERNAL-IP"},
+		model1.HeaderColumn{Name: "SELECTOR", Wide: true},
+		model1.HeaderColumn{Name: "PORTS", Wide: false},
+		model1.HeaderColumn{Name: "LABELS", Wide: true},
+		model1.HeaderColumn{Name: "VALID", Wide: true},
+		model1.HeaderColumn{Name: "AGE", Time: true},
 	}
 }
 
 // Render renders a K8s resource to screen.
-func (s Service) Render(o interface{}, ns string, r *Row) error {
+func (s Service) Render(o interface{}, ns string, r *model1.Row) error {
 	raw, ok := o.(*unstructured.Unstructured)
 	if !ok {
 		return fmt.Errorf("expected Service, but got %T", o)
@@ -49,7 +50,7 @@ func (s Service) Render(o interface{}, ns string, r *Row) error {
 	}
 
 	r.ID = client.MetaFQN(svc.ObjectMeta)
-	r.Fields = Fields{
+	r.Fields = model1.Fields{
 		svc.Namespace,
 		svc.ObjectMeta.Name,
 		string(svc.Spec.Type),
