@@ -442,7 +442,7 @@ func editRes(app *App, gvr client.GVR, path string) error {
 	if gvr.String() == "v1/namespaces" {
 		ns = n
 	}
-	if ok, err := app.Conn().CanI(ns, gvr.String(), n, []string{"patch"}); !ok || err != nil {
+	if ok, err := app.Conn().CanI(ns, gvr.String(), n, client.PatchAccess); !ok || err != nil {
 		return fmt.Errorf("current user can't edit resource %s", gvr)
 	}
 
