@@ -101,6 +101,19 @@ func (c *Command) contextCmd(p *cmd.Interpreter) error {
 	return c.exec(p, gvr, c.componentFor(gvr, ct, v), true)
 }
 
+func (c *Command) namespaceCmd(p *cmd.Interpreter) bool {
+	ns, ok := p.NSArg()
+	if !ok {
+		return false
+	}
+
+	if ns != "" {
+		_ = p.Reset("pod " + ns)
+	}
+
+	return false
+}
+
 func (c *Command) aliasCmd(p *cmd.Interpreter) error {
 	filter, _ := p.FilterArg()
 
@@ -157,7 +170,7 @@ func (c *Command) run(p *cmd.Interpreter, fqn string, clearStack bool) error {
 
 	if context, ok := p.HasContext(); ok {
 		if context != c.app.Config.ActiveContextName() {
-			if err := c.app.Config.Save(); err != nil {
+			if err := c.app.Config.Save(true); err != nil {
 				log.Error().Err(err).Msg("config save failed!")
 			} else {
 				log.Debug().Msgf("Saved context config for: %q", context)
@@ -244,6 +257,8 @@ func (c *Command) specialCmd(p *cmd.Interpreter) bool {
 		if err := c.contextCmd(p); err != nil {
 			c.app.Flash().Err(err)
 		}
+	case p.IsNamespaceCmd():
+		return c.namespaceCmd(p)
 	case p.IsDirCmd():
 		if a, ok := p.DirArg(); !ok {
 			c.app.Flash().Errf("Invalid command. Use `dir xxx`")
