@@ -5,6 +5,7 @@ package watch
 
 import (
 	"strings"
+	"time"
 
 	"github.com/derailed/k9s/internal/port"
 	"github.com/rs/zerolog/log"
@@ -38,7 +39,7 @@ type Forwarder interface {
 	SetActive(bool)
 
 	// Age returns forwarder age.
-	Age() string
+	Age() time.Time
 
 	// HasPortMapping returns true if port mapping exists.
 	HasPortMapping(string) bool
